@@ -137,7 +137,10 @@ static void AddExisting(const char *name, bool visible, bool duplicate)
 		AddSourceData data;
 		data.source = source;
 		data.visible = visible;
+
+		obs_enter_graphics();
 		obs_scene_atomic_update(scene, AddSource, &data);
+		obs_leave_graphics();
 
 		obs_source_release(source);
 	}
@@ -154,7 +157,7 @@ bool AddNew(QWidget *parent, const char *id, const char *name,
 
 	obs_source_t *source = obs_get_source_by_name(name);
 	if (source) {
-		QMessageBox::information(parent,
+		OBSMessageBox::information(parent,
 				QTStr("NameExists.Title"),
 				QTStr("NameExists.Text"));
 
@@ -165,7 +168,10 @@ bool AddNew(QWidget *parent, const char *id, const char *name,
 			AddSourceData data;
 			data.source = source;
 			data.visible = visible;
+
+			obs_enter_graphics();
 			obs_scene_atomic_update(scene, AddSource, &data);
+			obs_leave_graphics();
 
 			newSource = source;
 
@@ -190,7 +196,7 @@ void OBSBasicSourceSelect::on_buttonBox_accepted()
 		AddExisting(QT_TO_UTF8(item->text()), visible, false);
 	} else {
 		if (ui->sourceName->text().isEmpty()) {
-			QMessageBox::information(this,
+			OBSMessageBox::information(this,
 					QTStr("NoNameEntered.Title"),
 					QTStr("NoNameEntered.Text"));
 			return;
