@@ -165,6 +165,7 @@ struct DShowInput {
 	Device       device;
 	bool         deactivateWhenNotShowing = false;
 	bool         deviceHasAudio = false;
+	bool         deviceHasSeparateAudioFilter = false;
 	bool         flip = false;
 	bool         active = false;
 
@@ -403,6 +404,21 @@ static inline audio_format ConvertAudioFormat(AudioFormat format)
 	}
 }
 
+static inline enum speaker_layout convert_speaker_layout(uint8_t channels)
+{
+	switch (channels) {
+	case 0:     return SPEAKERS_UNKNOWN;
+	case 1:     return SPEAKERS_MONO;
+	case 2:     return SPEAKERS_STEREO;
+	case 3:     return SPEAKERS_2POINT1;
+	case 4:     return SPEAKERS_4POINT0;
+	case 5:     return SPEAKERS_4POINT1;
+	case 6:     return SPEAKERS_5POINT1;
+	case 8:     return SPEAKERS_7POINT1;
+	default:    return SPEAKERS_UNKNOWN;
+	}
+}
+
 //#define LOG_ENCODED_VIDEO_TS 1
 //#define LOG_ENCODED_AUDIO_TS 1
 
@@ -417,9 +433,9 @@ void DShowInput::OnEncodedVideoData(enum AVCodecID id,
 	}
 
 	bool got_output;
-	int len = ffmpeg_decode_video(video_decoder, data, size, &ts,
+	bool success = ffmpeg_decode_video(video_decoder, data, size, &ts,
 			&frame, &got_output);
-	if (len < 0) {
+	if (!success) {
 		blog(LOG_WARNING, "Error decoding video");
 		return;
 	}
@@ -516,11 +532,11 @@ void DShowInput::OnEncodedAudioData(enum AVCodecID id,
 		}
 	}
 
+	bool got_output = false;
 	do {
-		bool got_output;
-		int len = ffmpeg_decode_audio(audio_decoder, data, size,
+		bool success = ffmpeg_decode_audio(audio_decoder, data, size,
 				&audio, &got_output);
-		if (len < 0) {
+		if (!success) {
 			blog(LOG_WARNING, "Error decoding audio");
 			return;
 		}
@@ -537,9 +553,9 @@ void DShowInput::OnEncodedAudioData(enum AVCodecID id,
 
 		ts += int64_t(audio_decoder->frame->nb_samples) * 10000000LL /
 			int64_t(audio_decoder->frame->sample_rate);
-		size -= (size_t)len;
-		data += len;
-	} while (size > 0);
+		size = 0;
+		data = nullptr;
+	} while (got_output);
 }
 
 void DShowInput::OnAudioData(const AudioConfig &config,
@@ -559,7 +575,7 @@ void DShowInput::OnAudioData(const AudioConfig &config,
 		return;
 	}
 
-	audio.speakers        = (enum speaker_layout)config.channels;
+	audio.speakers        = convert_speaker_layout((uint8_t)config.channels);
 	audio.format          = ConvertAudioFormat(config.format);
 	audio.samples_per_sec = (uint32_t)config.sampleRate;
 	audio.data[0]         = data;
@@ -743,7 +759,6 @@ static inline bool IsEncoded(const VideoConfig &config)
 inline void DShowInput::SetupBuffering(obs_data_t *settings)
 {
 	BufferingType bufType;
-	uint32_t flags = obs_source_get_flags(source);
 	bool useBuffering;
 
 	bufType = (BufferingType)obs_data_get_int(settings, BUFFERING_VAL);
@@ -830,6 +845,7 @@ bool DShowInput::UpdateVideoConfig(obs_data_t *settings)
 	videoConfig.internalFormat   = format;
 
 	deviceHasAudio = dev.audioAttached;
+	deviceHasSeparateAudioFilter = dev.separateAudioFilter;
 
 	videoConfig.callback = std::bind(&DShowInput::OnVideoData, this,
 			placeholders::_1, placeholders::_2,
@@ -906,7 +922,8 @@ bool DShowInput::UpdateAudioConfig(obs_data_t *settings)
 		return true;
 	}
 
-	audioConfig.useVideoDevice = !useCustomAudio;
+	audioConfig.useVideoDevice = !useCustomAudio && !deviceHasSeparateAudioFilter;
+	audioConfig.useSeparateAudioFilter = deviceHasSeparateAudioFilter;
 
 	audioConfig.callback = std::bind(&DShowInput::OnAudioData, this,
 			placeholders::_1, placeholders::_2,
@@ -927,8 +944,12 @@ bool DShowInput::UpdateAudioConfig(obs_data_t *settings)
 	blog(LOG_INFO, "\tusing video device audio: %s",
 			audioConfig.useVideoDevice ? "yes" : "no");
 
-	if (!audioConfig.useVideoDevice)
-		blog(LOG_INFO, "\taudio device: %s", (const char*)name_utf8);
+	if (!audioConfig.useVideoDevice) {
+		if (audioConfig.useSeparateAudioFilter)
+			blog(LOG_INFO, "\tseparate audio filter");
+		else
+			blog(LOG_INFO, "\taudio device: %s", (const char*)name_utf8);
+	}
 
 	const char *mode = "";
 
